@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: data-lens-template
-version: 2.1.3
-id: data-lens-template-2.1.3-ae5d76d91cb8ea7c6c03f3e8c9e3f232
+version: 2.1.5
+id: data-lens-template-2.1.5-045413013b899bef8c019a7db754bedf
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Edward Kmett <ekmett@gmail.com>
 stability:
 homepage: http://github.com/ekmett/data-lens-template/
 package-url:
+synopsis: Utilities for Data.Lens
 description: Automatically derive @Lens@es for your data type for use with @Data.Lens@. Note: the code is derived from data-accessor-template <http://hackage.haskell.org/package/data-accessor-template> by Luke Palmer and Henning Thielemann.
 category: Data
 author: Joel Burget <joelburget@gmail.com>
@@ -16,21 +17,22 @@ pkgpath: devel/hs-data-lens-template
 exposed: True
 exposed-modules: Data.Lens.Template
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/data-lens-template-2.1.3
-library-dirs: /usr/local/lib/ghc/data-lens-template-2.1.3
-hs-libraries: HSdata-lens-template-2.1.3
+trusted: False
+import-dirs: /usr/local/lib/ghc/data-lens-template-2.1.5
+library-dirs: /usr/local/lib/ghc/data-lens-template-2.1.5
+hs-libraries: HSdata-lens-template-2.1.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         data-lens-2.0.2-b9e5a79561fc0e580f141215e526a069
-         template-haskell-2.5.0.0-4a39ca09d9a9f002b83c5a3730389e3d
+depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         data-lens-2.10.2-e2e5e12add54c150ab5e7c90446f5024
+         template-haskell-2.7.0.0-826c08e99d445bf7fa4a34d70f491207
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-data-lens-template-2.1.3/html/data-lens-template.haddock
-haddock-html: /usr/local/share/doc/hs-data-lens-template-2.1.3/html
+haddock-interfaces: /usr/local/share/doc/hs-data-lens-template-2.1.5/html/data-lens-template.haddock
+haddock-html: /usr/local/share/doc/hs-data-lens-template-2.1.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
